@@ -8,10 +8,10 @@ import yaml
 
 from geneflow.log import Log
 
-GF_VERSION = 'v1.0'
+GF_VERSION = 'v2.0'
 
 WORKFLOW_SCHEMA = {
-    'v1.0': {
+    'v2.0': {
         'gfVersion': {
             'type': 'string', 'default': GF_VERSION, 'allowed': [GF_VERSION]
         },
@@ -21,11 +21,11 @@ WORKFLOW_SCHEMA = {
         'workflow_id': {'type': 'string', 'default': ''},
         'name': {'type': 'string', 'required': True},
         'description': {'type': 'string', 'required': True},
-        'repo_uri': {'type': 'string', 'default': ''},
-        'documentation_uri': {'type': 'string', 'default': ''},
+        'git': {'type': 'string', 'default': ''},
         'version': {'type': 'string', 'required': True},
         'public': {'type': 'boolean', 'default': False},
         'enable': {'type': 'boolean', 'default': True},
+        'test': {'type': 'boolean', 'default': False},
         'username': {'type': 'string', 'default': 'user'},
         'inputs': {
             'type': 'dict',
@@ -42,10 +42,20 @@ WORKFLOW_SCHEMA = {
                         'default': 'Any',
                         'allowed': ['File', 'Directory', 'Any']
                     },
-                    'default': {'type': 'string', 'default': ''},
+                    'default': {
+                        'anyof': [
+                            {'type': 'string'},
+                            {'type': 'list', 'valueschema': {'type': 'string'}}
+                        ]
+                    },
                     'enable': {'type': 'boolean', 'default': True},
                     'visible': {'type': 'boolean', 'default': True},
-                    'value': {'type': 'string', 'default': ''}
+                    'value': {
+                        'anyof': [
+                            {'type': 'string'},
+                            {'type': 'list', 'valueschema': {'type': 'string'}}
+                        ]
+                    }
                 }
             }
         },
@@ -77,6 +87,18 @@ WORKFLOW_SCHEMA = {
         'final_output': {
             'type': 'list', 'schema': {'type': 'string'}, 'default': []
         },
+        'apps': {
+            'type': 'dict',
+            'required': True,
+            'valueschema': {
+                'type': 'dict',
+                'required': True,
+                'schema': {
+                    'git': {'type': 'string', 'required': True},
+                    'version': {'type': 'string', 'nullable': True, 'default': None},
+                }
+            }
+        },
         'steps': {
             'type': 'dict',
             'required': True,
@@ -102,9 +124,10 @@ WORKFLOW_SCHEMA = {
                     'letter': {'type': 'string', 'default': ''},
                     'map': {
                         'type': 'dict',
-                        'default': {'uri': '', 'regex': ''},
+                        'default': {'uri': '', 'regex': '', 'glob': '*'},
                         'schema': {
                             'uri': {'type': 'string', 'default': ''},
+                            'glob': {'type': 'string', 'default': '*'},
                             'regex': {'type': 'string', 'default': ''}
                         }
                     },
@@ -117,26 +140,21 @@ WORKFLOW_SCHEMA = {
                     },
                     'execution': {
                         'type': 'dict',
-                        'default': {'context': 'local', 'method': 'auto'},
+                        'default': {'context': 'local', 'method': 'auto', 'parameters': {}},
                         'schema': {
                             'context': {
                                 'type': 'string',
                                 'default': 'local',
-                                'allowed': ['local', 'agave']
+                                'allowed': ['local', 'agave', 'tapis', 'gridengine', 'slurm']
                             },
                             'method': {
                                 'type': 'string',
-                                'default': 'auto',
-                                'allowed': [
-                                    'auto',
-                                    'package',
-                                    'cdc-shared-package',
-                                    'singularity',
-                                    'cdc-shared-singularity',
-                                    'docker',
-                                    'environment',
-                                    'module'
-                                ]
+                                'default': 'auto'
+                            },
+                            'parameters': {
+                                'type': 'dict',
+                                'allow_unknown': True,
+                                'default': {}
                             }
                         }
                     }
@@ -147,7 +165,7 @@ WORKFLOW_SCHEMA = {
 }
 
 APP_SCHEMA = {
-    'v1.0': {
+    'v2.0': {
         'gfVersion': {
             'type': 'string',
             'default': GF_VERSION,
@@ -161,8 +179,8 @@ APP_SCHEMA = {
         'app_id': {'type': 'string', 'default': ''},
         'name': {'type': 'string', 'required': True},
         'description': {'type': 'string', 'maxlength': 64, 'required': True},
-        'repo_uri': {'type': 'string', 'default': ''},
-        'version': {'type': 'string', 'default': ''},
+        'git': {'type': 'string', 'default': ''},
+        'version': {'type': 'string', 'required': True},
         'public': {'type': 'boolean', 'default': True},
         'username': {'type': 'string', 'default': 'user'},
         'inputs': {
@@ -181,7 +199,15 @@ APP_SCHEMA = {
                         'allowed': ['File', 'Directory', 'Any']
                     },
                     'default': {'type': 'string', 'default': ''},
-                    'value': {'type': 'string', 'default': ''}
+                    'value': {'type': 'string', 'default': ''},
+                    'script_default': {'type': 'string', 'nullable': True},
+                    'required': {'type': 'boolean', 'default': False},
+                    'test_value': {'type': 'string', 'nullable': True},
+                    'post_exec': {
+                        'type': 'list',
+                        'schema': {'type': 'dict'},
+                        'nullable': True
+                    }
                 }
             }
         },
@@ -204,20 +230,30 @@ APP_SCHEMA = {
                         ]
                     },
                     'default': {'nullable': True, 'default': None},
-                    'value': {'nullable': True, 'default': None}
+                    'value': {'nullable': True, 'default': None},
+                    'required': {'type': 'boolean', 'default': False},
+                    'test_value': {'nullable': True},
+                    'post_exec': {
+                        'type': 'list',
+                        'schema': {'type': 'dict'},
+                        'nullable': True
+                    }
                 }
             }
         },
-        'definition': {
+        'pre_exec': {'type': 'list', 'default': []},
+        'exec_methods': {'type': 'list', 'default': []},
+        'post_exec': {'type': 'list', 'default': []},
+        'implementation': {
             'type': 'dict',
-            'required': True,
+            'required': False,
             'valueschema': {'type': 'dict'}
         }
     }
 }
 
 JOB_SCHEMA = {
-    'v1.0': {
+    'v2.0': {
         'gfVersion': {
             'type': 'string',
             'default': GF_VERSION,
@@ -245,7 +281,14 @@ JOB_SCHEMA = {
             'coerce': (lambda s: str(s).lower() in ['true','yes','1'])
         },
         'inputs': {
-            'type': 'dict', 'default': {}, 'valueschema': {'type': 'string'}
+            'type': 'dict',
+            'default': {},
+            'valueschema': {
+                'anyof': [
+                    {'type': 'string'},
+                    {'type': 'list', 'schema': {'type': 'string'}}
+                ]
+            }
         },
         'parameters': {
             'type': 'dict', 'default': {}
@@ -257,7 +300,8 @@ JOB_SCHEMA = {
             'type': 'dict',
             'default': {
                 'context': {'default': 'local'},
-                'method': {'default': 'auto'}
+                'method': {'default': 'auto'},
+                'parameters': {'default': {}}
             },
             'schema': {
                 'context': {
@@ -273,7 +317,13 @@ JOB_SCHEMA = {
                     'valueschema': {
                         'type': 'string',
                         'default': 'local',
-                        'allowed': ['local', 'agave']
+                        'allowed': [
+                            'local',
+                            'agave',
+                            'tapis',
+                            'gridengine',
+                            'slurm'
+                        ]
                     }
                 },
                 'method': {
@@ -288,17 +338,24 @@ JOB_SCHEMA = {
                     },
                     'valueschema': {
                         'type': 'string',
-                        'default': 'auto',
-                        'allowed': [
-                            'auto',
-                            'package',
-                            'cdc-shared-package',
-                            'singularity',
-                            'cdc-shared-singularity',
-                            'docker',
-                            'environment',
-                            'module'
-                        ]
+                        'default': 'auto'
+                    }
+                },
+                'parameters': {
+                    'type': 'dict',
+                    'default': {'default': {}},
+                    'allow_unknown': True,
+                    'schema': {
+                        'default': {
+                            'type': 'dict',
+                            'default': {},
+                            'allow_unknown': True
+                        }
+                    },
+                    'valueschema': {
+                        'type': 'dict',
+                        'default': {},
+                        'allow_unknown': True
                     }
                 }
             }
